PartialConfig class

Mixed-in types
Implementers
Annotations
  • @JsonSerializable.new()

Constructors

PartialConfig({required Map<String, String?>? variableConfig})
const
PartialConfig.fromJson(Map json)
factory
PartialConfig.self(PartialConfig? config)

Properties

combine → List<Iterable<(String, String)>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
variableConfig → Map<String, String?>?
final
variablesToProcess → List
no setteroverride
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited