StringOr<T extends Object> class

Constructors

StringOr({String? string, T? object})
const
StringOr.fromJson(dynamic json, T fromJsonT(Object? value))
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isObject → bool
no setter
isString → bool
no setter
object → T?
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String?
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T value)) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited