ContentReplacement class

The result of content replacement

Annotations
  • @autoequal

Constructors

ContentReplacement({required String content, required Set<String> used, Map<String, dynamic> data = const {}})
The result of content replacement
const

Properties

content → String
the new content
final
data → Map<String, dynamic>
any additional data that needs to be returned
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
used → Set<String>
the variables used in the content
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited