FileWriteResult class

returns the used partials and variables of the written file

Annotations
  • @autoequal

Constructors

FileWriteResult({required Set<String> usedPartials, required Set<String> usedVariables})
returns the used partials and variables of the written file
const
FileWriteResult.empty()
returns the used partials and variables of the written file
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
usedPartials → Set<String>
the paths of the partials used in the file
final
usedVariables → Set<String>
the names of the variables used in the file
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited