BrickImpl class

A brick is a collection of files that can be copied, altered, and/or generated into a new project.

Inheritance

Constructors

BrickImpl(BrickConfig config, {required String name, required String? outputDir, required bool watch, required bool shouldSync})
A brick is a collection of files that can be copied, altered, and/or generated into a new project.

Properties

brick → BrickConfig
no setterinherited
combine → List<Iterable<(String, String)>>
no setterinherited
configPath → String?
finalinherited
directories → Iterable<Directory>
The list of directories that are configured for the brick
no setteroverride
directoryConfigs → Map<String, DirectoryConfig>?
finalinherited
exclude → List<String>?
finalinherited
fileConfigs → Map<String, FileConfig>?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isBrick → bool
no setterinherited
isReference → bool
no setterinherited
masonBrick → MasonBrick?
The brick's config file to be consumed by mason
final
masonBrickConfig → StringOr<MasonBrickConfig>?
finalinherited
name → String
the name of the brick
final
outputDir → String
the directory to output the brick to
final
partialConfigs → Map<String, PartialConfig?>?
finalinherited
partials → Iterable<Partial>
The list of partials that are configured for the brick
no setteroverride
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
reference → BrickConfigReference
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldSync → bool
Whether to validate the brick.yaml file. That all inputs are valid and consumed
final
source → Source
the source files for the brick
no setteroverride
sourcePath → String
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
urlConfigs → Map<String, UrlConfig>?
finalinherited
urls → Iterable<Url>
The list of urls that are configured for the brick
no setteroverride
variables → Iterable<Variable>
retrieves all variables from the VarsMixin.varsMap
no setterinherited
variablesToProcess → List
no setterinherited
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited
watch → bool
Whether the brick's sourcePath is being watched to react to file changes
final
watcher → SourceWatcher
the file system watcher for the brick
no setteroverride

Methods

cook() → void
cooks the brick, and outputs the files to outputDir
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({required String fromPath}) → BrickConfig
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited