NameImpl class

Inheritance

Constructors

NameImpl(NameConfig config, {required String originalName})

Properties

braces → int
finalinherited
combine → List<Iterable<(String, String)>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
originalName → String
final
prefix → String
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
renameWith → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → StringOr<SectionConfig>?
finalinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
suffix → String
finalinherited
tag → MustacheTag?
finalinherited
variables → Iterable<Variable>
retrieves all variables from the VarsMixin.varsMap
no setterinherited
variablesToProcess → List
no setterinherited
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited

Methods

format({String trailing = '', String postStartBraces = '', String preEndBraces = ''}) → String
returns the name of the file with formatting to mustache
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited