SourceImpl class

The base class for where a brick is sourced from

Inheritance

Constructors

SourceImpl(String path, {required String targetDir, required Iterable<String> excludePaths, required Map<String, FileConfig> fileConfigs})
The base class for where a brick is sourced from
const

Properties

excludePaths → Iterable<String>
The paths to exclude from the source
final
fileConfigs → Map<String, FileConfig>
The files that are has been configured and need to be cooked
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
The path to the source
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDir → String
where the source files are copied to
finalinherited

Methods

combineFiles() → List<TargetFile>
returns all targetFileConfigs and fileConfigs
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathFromSource(String path) → String
Returns the path to the source file
override
targetFileConfigs() → List<String>
returns all paths from source, mapped to the
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited