UrlImpl class

A url is a collection of files that can be copied, altered, and/or generated into a new project.

Inheritance

Constructors

UrlImpl(UrlConfig config, {required String path})
A url is a collection of files that can be copied, altered, and/or generated into a new project.

Properties

combine → List<Iterable<(String, String)>>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
include → Include?
final
includeConfig → IncludeConfig?
finalinherited
name → Name
final
nameConfig → NameConfig?
finalinherited
path → String
the path to the url
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
variables → Iterable<Variable>
retrieves all variables from the VarsMixin.varsMap
no setterinherited
variablesToProcess → List
no setterinherited
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited

Methods

formatName() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited