Partial class abstract

The base class for a partial file

Inheritance
Mixed-in types
Implementers

Constructors

Partial(PartialConfig? config)
The base class for a partial file

Properties

combine → List<Iterable<(String, String)>>
no setterinherited
fileName → String
returns the file name and extension of the partial
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
the name of the partial
no setter
outputDir → String
The path to where the partial will be written
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFile → String
The path to where the partial is located
no setter
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
variableConfig → Map<String, String?>?
finalinherited
variables → Iterable<Variable>
retrieves all variables from the VarsMixin.varsMap
no setterinherited
variablesToProcess → List
no setterinherited
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toPartialFile() → String
returns the fileName wrapped with {{> and }}
toPartialInput() → String
returns the fileName wrapped with {{~ and }}
toString() → String
A string representation of this object.
inherited
write({required Iterable<Partial> partials, required Set<Variable> outOfFileVariables}) → FileWriteResult
writes the partial to the target file

Operators

operator ==(Object other) → bool
The equality operator.
inherited