Source class abstract

The base class for where a brick is sourced from

Implementers

Constructors

Source(String path, {required String targetDir})
The base class for where a brick is sourced from
const

Properties

excludePaths → Iterable<String>
The paths to exclude from the source
no setter
fileConfigs → Map<String, FileConfig>
The files that are has been configured and need to be cooked
no setter
hashCode → int
The hash code for this object.
no setterinherited
path → String
The path to the source
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDir → String
where the source files are copied to
final

Methods

combineFiles() → List<TargetFile>
returns all targetFileConfigs and fileConfigs
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathFromSource(String path) → String
Returns the path to the source file
targetFileConfigs() → List<String>
returns all paths from source, mapped to the
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited