TargetFile class abstract

A target file is a file that can be copied, altered, and/or generated into a new project.

Inheritance
Mixed-in types
Implementers

Constructors

TargetFile(FileConfig? config)
A target file is a file that can be copied, altered, and/or generated into a new project.

Properties

combine → List<Iterable<(String, String)>>
no setterinherited
extension → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
include → Include?
no setter
includeConfig → IncludeConfig?
finalinherited
name → Name?
the name of the file
no setter
nameConfig → StringOr<NameConfig>?
finalinherited
pathWithoutSourceDir → String
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourcePath → String
the path to the source file
no setter
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
targetDir → String
the path to the target file
no setter
variableConfig → Map<String, String?>?
finalinherited
variables → Iterable<Variable>
retrieves all variables from the VarsMixin.varsMap
no setterinherited
variablesToProcess → List
no setterinherited
vars → Iterable<String>
no setterinherited
varsMap → Set<(String, String)>
no setterinherited

Methods

configurePath({required Iterable<Url> urls, required Iterable<Directory> dirs}) → ContentReplacement
updates the file path with the provided urls and dirs replacing the appropriate segments and file name
formatName() → String
the name of file with extension
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
write({required Brick brick, required Set<Variable> outOfFileVariables}) → FileWriteResult
the path to the target file

Operators

operator ==(Object other) → bool
The equality operator.
inherited