Constants class

Constants used throughout the package

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultVariables → Set<Variable>
variables used not provided by the user
no setter
excludedDirs → List<String>
no setter
variablesToIgnore → List<String>
variables to ignore configuring the target file
no setter

Constants

kDefaultBraces → const int
the default number of braces to wrap a variable with
kIndexValue → const String
the value to be used for when accessing the current value of an array
packageName → const String
The name of the package